@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <math.h>
@@ -17,7 +16,10 @@
 #include "util.h"
 #include "legacy/gsm_color_button.h"
 
-gchar * format_duration (unsigned seconds);
+constexpr double BORDER_ALPHA = 0.7;
+constexpr double GRID_ALPHA = BORDER_ALPHA / 2.0;
+constexpr int FRAME_WIDTH = 4;
+constexpr unsigned GRAPH_MIN_HEIGHT = 40;
 
 void
 LoadGraph::clear_background ()
@@ -124,7 +126,7 @@ LoadGraph::translate_to_log_partial_if_needed (float position_partial)
   return position_partial;
 }
 
-gchar*
+static gchar*
 format_duration (unsigned seconds)
 {
   gchar*caption = NULL;
@@ -172,31 +174,52 @@ format_duration (unsigned seconds)
   return caption;
 }
 
-const int FRAME_WIDTH = 4;
 static void
-draw_background (LoadGraph *graph)
+force_refresh (LoadGraph * const graph)
+{
+    graph->clear_background ();
+    load_graph_queue_draw (graph);
+}
+
+static void
+load_graph_rescale (LoadGraph *graph) {
+    ///org/gnome/desktop/interface/text-scaling-factor
+    graph->fontsize = 8 * graph->font_settings->get_double ("text-scaling-factor");
+    force_refresh (graph);
+}
+
+static void
+load_graph_state_changed (GtkWidget     *widget,
+                          GtkStateFlags *flags,
+                          gpointer       data_ptr)
+{
+    LoadGraph * const graph = static_cast<LoadGraph*>(data_ptr);
+
+    force_refresh (graph);
+    graph->draw = gtk_widget_is_visible (widget);
+}
+
+static cairo_surface_t*
+create_background (LoadGraph *graph)
 {
   GtkAllocation allocation;
   cairo_t *cr;
-  guint i;
-  double label_x_offset_modifier, label_y_offset_modifier;
   unsigned num_bars;
-  gchar *caption;
-  PangoLayout*layout;
-  PangoAttrList *attrs = NULL;
-  PangoFontDescription*font_desc;
-  PangoRectangle extents;
+  PangoFontDescription *font_desc;
+  PangoLayout *layout;
   cairo_surface_t *surface;
   GdkRGBA fg;
   GdkRGBA fg_grid;
-  double const border_alpha = 0.7;
-  double const grid_alpha = border_alpha / 2.0;
 
+  /* Graph length */
+  const unsigned total_seconds = graph->speed * (graph->num_points - 2) / 1000 * graph->frames_per_unit;
+
+  /* Initialize graph dimensions */
   num_bars = graph->num_bars ();
   graph->graph_dely = (graph->draw_height - 15) / num_bars;   /* round to int to avoid AA blur */
-  graph->real_draw_height = graph->graph_dely * num_bars;
-  graph->graph_delx = (graph->draw_width - 2.0 - graph->indent) / (graph->num_points - 3);
+  graph->graph_delx = (graph->draw_width - 2 - graph->indent) / (graph->num_points - 3);
   graph->graph_buffer_offset = (int) (1.5 * graph->graph_delx) + FRAME_WIDTH;
+  graph->real_draw_height = graph->graph_dely * num_bars;
 
   gtk_widget_get_allocation (GTK_WIDGET (graph->disp), &allocation);
   surface = gdk_window_create_similar_surface (gtk_widget_get_window (GTK_WIDGET (graph->disp)),
@@ -209,13 +232,8 @@ draw_background (LoadGraph *graph)
 
   gtk_style_context_get_color (context, gtk_widget_get_state_flags (GTK_WIDGET (GsmApplication::get ()->stack)), &fg);
 
-  cairo_paint_with_alpha (cr, 0.0);
   layout = pango_cairo_create_layout (cr);
 
-  attrs = make_tnum_attr_list ();
-  pango_layout_set_attributes (layout, attrs);
-  g_clear_pointer (&attrs, pango_attr_list_unref);
-
   gtk_style_context_get (context, gtk_widget_get_state_flags (GTK_WIDGET (GsmApplication::get ()->stack)), GTK_STYLE_PROPERTY_FONT, &font_desc, NULL);
   pango_font_description_set_size (font_desc, 0.8 * graph->fontsize * PANGO_SCALE);
   pango_layout_set_font_description (layout, font_desc);
@@ -255,10 +273,11 @@ draw_background (LoadGraph *graph)
 
   cairo_set_line_width (cr, 1.0);
 
-  for (i = 0; i <= num_bars; ++i)
+  for (guint i = 0; i <= num_bars; i++)
     {
-      double y;
+      PangoRectangle extents;
 
+      double y;
       if (i == 0)
         y = 0.5 + graph->fontsize / 2.0;
       else if (i == num_bars)
@@ -267,11 +286,10 @@ draw_background (LoadGraph *graph)
         y = i * graph->graph_dely + graph->fontsize / 2.0;
 
       gdk_cairo_set_source_rgba (cr, &fg);
-      caption = graph->get_caption (i);
-      pango_layout_set_alignment (layout, PANGO_ALIGN_LEFT);
+      gchar *caption = graph->get_caption (i);
       pango_layout_set_text (layout, caption, -1);
       pango_layout_get_extents (layout, NULL, &extents);
-      label_y_offset_modifier = i == 0 ? 0.5
+      double label_y_offset_modifier = i == 0 ? 0.5
                                 : i == num_bars
                                     ? 1.0
                                     : 0.85;
@@ -281,43 +299,41 @@ draw_background (LoadGraph *graph)
       g_free (caption);
 
       if (i == 0 || i == num_bars)
-        fg_grid.alpha = border_alpha;
+        fg_grid.alpha = BORDER_ALPHA;
       else
-        fg_grid.alpha = grid_alpha;
+        fg_grid.alpha = GRID_ALPHA;
 
       gdk_cairo_set_source_rgba (cr, &fg_grid);
-      cairo_move_to (cr, graph->indent, i * graph->graph_dely + 0.5);
-      cairo_line_to (cr, graph->draw_width - graph->rmargin + 0.5 + 4, i * graph->graph_dely + 0.5);
+      cairo_move_to (cr, graph->indent, i * graph->graph_dely);
+      cairo_line_to (cr, graph->draw_width - graph->rmargin + 4, i * graph->graph_dely);
       cairo_stroke (cr);
     }
 
-
-  const unsigned total_seconds = graph->speed * (graph->num_points - 2) / 1000 * graph->frames_per_unit;
-
   for (unsigned int i = 0; i < 7; i++)
     {
-      double x = (i) * (graph->draw_width - graph->rmargin - graph->indent) / 6;
+      PangoRectangle extents;
+
+      double x = ceil (i * (graph->draw_width - graph->rmargin - graph->indent) / 6);
 
       if (i == 0 || i == 6)
-        fg_grid.alpha = border_alpha;
+        fg_grid.alpha = BORDER_ALPHA;
       else
-        fg_grid.alpha = grid_alpha;
+        fg_grid.alpha = GRID_ALPHA;
 
       gdk_cairo_set_source_rgba (cr, &fg_grid);
-      cairo_move_to (cr, (ceil (x) + 0.5) + graph->indent, 0.5);
-      cairo_line_to (cr, (ceil (x) + 0.5) + graph->indent, graph->real_draw_height + 4.5);
+      cairo_move_to (cr, x + graph->indent, 0);
+      cairo_line_to (cr, x + graph->indent, graph->real_draw_height + 4);
       cairo_stroke (cr);
 
-      caption = format_duration (total_seconds - i * total_seconds / 6);
-
+      gchar *caption = format_duration (total_seconds - i * total_seconds / 6);
       pango_layout_set_text (layout, caption, -1);
       pango_layout_get_extents (layout, NULL, &extents);
-      label_x_offset_modifier = i == 0 ? 0
+      double label_x_offset_modifier = i == 0 ? 0
                                          : i == 6
                                             ? 1.0
                                             : 0.5;
       cairo_move_to (cr,
-                     (ceil (x) + 0.5 + graph->indent) - label_x_offset_modifier * extents.width / PANGO_SCALE + 1.0,
+                     x + graph->indent - label_x_offset_modifier * extents.width / PANGO_SCALE + 1.0,
                      graph->draw_height - 1.0 * extents.height / PANGO_SCALE);
       gdk_cairo_set_source_rgba (cr, &fg);
       pango_cairo_show_layout (cr, layout);
@@ -326,28 +342,8 @@ draw_background (LoadGraph *graph)
   g_object_unref (layout);
   cairo_stroke (cr);
   cairo_destroy (cr);
-  graph->background = surface;
-}
 
-/* Redraws the backing buffer for the load graph and updates the window */
-void
-load_graph_queue_draw (LoadGraph *graph)
-{
-  /* repaint */
-  gtk_widget_queue_draw (GTK_WIDGET (graph->disp));
-}
-
-void       load_graph_update_data (LoadGraph *graph);
-static int load_graph_update (gpointer user_data); // predeclare load_graph_update so we can compile ;)
-
-static void
-load_graph_rescale (LoadGraph *graph)
-{
-  ///org/gnome/desktop/interface/text-scaling-factor
-  graph->fontsize = 8 * graph->font_settings->get_double ("text-scaling-factor");
-  graph->clear_background ();
-
-  load_graph_queue_draw (graph);
+  return surface;
 }
 
 static gboolean
@@ -371,13 +367,6 @@ load_graph_configure (GtkWidget         *widget,
   return TRUE;
 }
 
-static void
-force_refresh (LoadGraph * const graph)
-{
-  graph->clear_background ();
-  load_graph_queue_draw (graph);
-}
-
 static void
 load_graph_style_updated (GtkWidget *widget,
                           gpointer   data_ptr)
@@ -387,18 +376,6 @@ load_graph_style_updated (GtkWidget *widget,
   force_refresh (graph);
 }
 
-static gboolean
-load_graph_state_changed (GtkWidget     *widget,
-                          GtkStateFlags *flags,
-                          gpointer       data_ptr)
-{
-  LoadGraph * const graph = static_cast<LoadGraph*>(data_ptr);
-
-  force_refresh (graph);
-  graph->draw = gtk_widget_is_visible (widget);
-  return TRUE;
-}
-
 static gboolean
 load_graph_draw (GtkWidget *widget,
                  cairo_t   *cr,
@@ -406,69 +383,67 @@ load_graph_draw (GtkWidget *widget,
 {
   LoadGraph * const graph = static_cast<LoadGraph*>(data_ptr);
 
-  guint i;
-  gint j;
-  gdouble sample_width, x_offset;
-
   /* Number of pixels wide for one sample point */
-  sample_width = (double)(graph->draw_width - graph->rmargin - graph->indent) / (double)graph->num_points;
+  gdouble sample_width = (double)(graph->draw_width - graph->rmargin - graph->indent) / (double)graph->num_points;
   /* Lines start at the right edge of the drawing,
    * a bit outside the clip rectangle. */
-  x_offset = graph->draw_width - graph->rmargin + sample_width + 2;
+  gdouble x_offset = graph->draw_width - graph->rmargin + sample_width;
   /* Adjustment for smooth movement between samples */
   x_offset -= sample_width * graph->render_counter / (double)graph->frames_per_unit;
 
   /* draw the graph */
 
   if (graph->background == NULL)
-    draw_background (graph);
+    graph->background = create_background (graph);
   cairo_set_source_surface (cr, graph->background, 0, 0);
   cairo_paint (cr);
 
   cairo_set_line_width (cr, 1);
   cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
   cairo_set_line_join (cr, CAIRO_LINE_JOIN_ROUND);
-  cairo_rectangle (cr, graph->indent + FRAME_WIDTH + 1, FRAME_WIDTH - 1,
-                   graph->draw_width - graph->rmargin - graph->indent - 1,
-                   graph->real_draw_height + FRAME_WIDTH - 1);
+  cairo_rectangle (cr, graph->indent + FRAME_WIDTH, FRAME_WIDTH,
+                   graph->draw_width - graph->rmargin - graph->indent,
+                   graph->real_draw_height);
   cairo_clip (cr);
 
+  /* The clipped region does not start from y == 0 but from FRAME_WIDTH */
+  gint draw_height = graph->real_draw_height + FRAME_WIDTH;
+
   bool drawStacked = graph->type == LOAD_GRAPH_CPU && GsmApplication::get ()->config.draw_stacked;
   bool drawSmooth = GsmApplication::get ()->config.draw_smooth;
 
-  for (j = graph->n - 1; j >= 0; j--)
+  for (gint j = graph->n - 1; j >= 0; j--)
     {
       gdk_cairo_set_source_rgba (cr, &(graph->colors [j]));
       // Start drawing on the right at the correct height.
-      cairo_move_to (cr, x_offset, (1.0f - graph->data[0][j]) * graph->real_draw_height + 3);
-      // then draw the path of the line.
-      // Loop starts at 1 because the curve accesses the 0th data point.
-      for (i = 1; i < graph->num_points; ++i)
+      cairo_move_to (cr, x_offset, (1.0f - graph->data[0][j]) * draw_height);
+      /* Draw the path of the line
+         Loop starts at 1 because the curve accesses the 0th data point */
+      for (gint i = 1; i < graph->num_points; i++)
         {
           if (graph->data[i][j] == -1.0f)
             continue;
           if (drawSmooth)
             cairo_curve_to (cr,
                             x_offset - ((i - 0.5f) * graph->graph_delx),
-                            (1.0 - graph->data[i - 1][j]) * graph->real_draw_height + 3,
+                            (1.0 - graph->data[i - 1][j]) * draw_height,
                             x_offset - ((i - 0.5f) * graph->graph_delx),
-                            (1.0 - graph->data[i][j]) * graph->real_draw_height + 3,
+                            (1.0 - graph->data[i][j]) * draw_height,
                             x_offset - (i * graph->graph_delx),
-                            (1.0 - graph->data[i][j]) * graph->real_draw_height + 3);
+                            (1.0 - graph->data[i][j]) * draw_height);
           else
             cairo_line_to (cr, x_offset - (i * graph->graph_delx),
-                           (1.0 - graph->data[i][j]) * graph->real_draw_height + 3);
+                           (1.0 - graph->data[i][j]) * draw_height);
         }
       if (drawStacked)
         {
           // Draw the remaining outline of the area:
           // Left bottom corner
-          cairo_rel_line_to (cr, 0, graph->real_draw_height + 3);
+          cairo_rel_line_to (cr, 0, draw_height);
           // Right bottom corner. It's drawn far outside the visible area
           // to avoid a weird bug where it's not filling the area it should completely.
           cairo_rel_line_to (cr, x_offset * 2, 0);
 
-          //cairo_stroke_preserve(cr);
           cairo_close_path (cr);
           cairo_fill (cr);
         }
@@ -552,10 +527,7 @@ get_load (LoadGraph *graph)
   graph->cpu.now ^= 1;
 }
 
-
-namespace
-{
-void
+static void
 set_memory_label_and_picker (GtkLabel      *label,
                              GsmColorButton*picker,
                              guint64        used,
@@ -598,7 +570,6 @@ set_memory_label_and_picker (GtkLabel      *label,
   if (picker)
     gsm_color_button_set_fraction (picker, percent);
 }
-}
 
 static void
 get_memory (LoadGraph *graph)
@@ -868,9 +839,7 @@ get_net (LoadGraph *graph)
   gtk_label_set_text (GTK_LABEL (graph->labels.net_out_total), procman::format_network (out).c_str ());
 }
 
-
-
-void
+static void
 load_graph_update_data (LoadGraph *graph)
 {
   // Rotate data one element down.
@@ -923,40 +892,23 @@ load_graph_update (gpointer user_data)
   return TRUE;
 }
 
-
-
-LoadGraph::~LoadGraph()
-{
-  load_graph_stop (this);
-
-  if (timer_index)
-    g_source_remove (timer_index);
-
-  clear_background ();
-}
-
-
-
-static gboolean
+static void
 load_graph_destroy (GtkWidget *widget,
                     gpointer   data_ptr)
 {
   LoadGraph * const graph = static_cast<LoadGraph*>(data_ptr);
 
   delete graph;
-
-  return FALSE;
 }
 
-
 LoadGraph::LoadGraph(guint type)
   : fontsize (8.0),
   rmargin (6 * fontsize),
   indent (18.0),
   n (0),
   type (type),
-  speed (0),
-  num_points (0),
+  speed (GsmApplication::get ()->config.graph_update_interval),
+  num_points (GsmApplication::get ()->config.graph_data_points + 2),
   latest (0),
   draw_width (0),
   draw_height (0),
@@ -964,7 +916,7 @@ LoadGraph::LoadGraph(guint type)
   frames_per_unit (10),    // this will be changed but needs initialising
   graph_dely (0),
   real_draw_height (0),
-  graph_delx (0.0),
+  graph_delx (0),
   graph_buffer_offset (0),
   colors (),
   data_block (),
@@ -981,8 +933,6 @@ LoadGraph::LoadGraph(guint type)
   cpu (),
   net ()
 {
-  LoadGraph * const graph = this;
-
   font_settings->signal_changed (FONT_SETTING_SCALING).connect ([this](const Glib::ustring&) {
     load_graph_rescale (this);
   });
@@ -1044,10 +994,6 @@ LoadGraph::LoadGraph(guint type)
         break;
     }
 
-  speed = GsmApplication::get ()->config.graph_update_interval;
-
-  num_points = GsmApplication::get ()->config.graph_data_points + 2;
-
   colors.resize (n);
 
   switch (type)
@@ -1073,26 +1019,24 @@ LoadGraph::LoadGraph(guint type)
         break;
     }
 
-  timer_index = 0;
   render_counter = (frames_per_unit - 1);
-  draw = FALSE;
 
   main_widget = GTK_BOX (gtk_box_new (GTK_ORIENTATION_VERTICAL, 6));
-  gtk_widget_set_size_request (GTK_WIDGET (main_widget), -1, LoadGraph::GRAPH_MIN_HEIGHT);
+  gtk_widget_set_size_request (GTK_WIDGET (main_widget), -1, GRAPH_MIN_HEIGHT);
   gtk_widget_show (GTK_WIDGET (main_widget));
 
   disp = GTK_DRAWING_AREA (gtk_drawing_area_new ());
   gtk_widget_show (GTK_WIDGET (disp));
   g_signal_connect (G_OBJECT (disp), "draw",
-                    G_CALLBACK (load_graph_draw), graph);
+                    G_CALLBACK (load_graph_draw), this);
   g_signal_connect (G_OBJECT (disp), "configure_event",
-                    G_CALLBACK (load_graph_configure), graph);
+                    G_CALLBACK (load_graph_configure), this);
   g_signal_connect (G_OBJECT (disp), "destroy",
-                    G_CALLBACK (load_graph_destroy), graph);
+                    G_CALLBACK (load_graph_destroy), this);
   g_signal_connect (G_OBJECT (disp), "state-flags-changed",
-                    G_CALLBACK (load_graph_state_changed), graph);
+                    G_CALLBACK (load_graph_state_changed), this);
   g_signal_connect (G_OBJECT (disp), "style-updated",
-                    G_CALLBACK (load_graph_style_updated), graph);
+                    G_CALLBACK (load_graph_style_updated), this);
 
   gtk_widget_set_events (GTK_WIDGET (disp), GDK_EXPOSURE_MASK);
 
@@ -1108,6 +1052,24 @@ LoadGraph::LoadGraph(guint type)
   gtk_widget_show_all (GTK_WIDGET (main_widget));
 }
 
+LoadGraph::~LoadGraph()
+{
+  load_graph_stop (this);
+
+  if (timer_index)
+    g_source_remove (timer_index);
+
+  clear_background ();
+}
+
+/* Redraws the backing buffer for the load graph and updates the window */
+void
+load_graph_queue_draw (LoadGraph *graph)
+{
+    /* repaint */
+    gtk_widget_queue_draw (GTK_WIDGET (graph->disp));
+}
+
 void
 load_graph_start (LoadGraph *graph)
 {
